import { useEffect, useState } from "react";
import {
	Box,
	Button,
	Typography,
	TextField,
	InputAdornment,
	Paper,
	Table,
	TableBody,
	TableCell,
	TableContainer,
	TableHead,
	TableRow,
	Pagination,
	IconButton,
} from "@mui/material";
import SearchIcon from "@mui/icons-material/Search";
import MoreHorizIcon from "@mui/icons-material/MoreHoriz";
import TuneIcon from "@mui/icons-material/Tune";
import { useDispatch, useSelector } from "react-redux";
import { adminList } from "../../redux/slices/adminSlice";
import { AppDispatch, RootState } from "../../redux/store/store";

export default function AdminList() {
	const [searchQuery, setSearchQuery] = useState("");
	const [currentPage, setCurrentPage] = useState(1);
	const adminsPerPage = 10;

	const dispatch = useDispatch<AppDispatch>();
	const admins = useSelector((state: RootState) => state.adminReducer.admins);

	useEffect(() => {
		dispatch(adminList());
	}, [dispatch]);

	const staticAdmins = [
		{
			name: "John Doe",
			location: "New York",
			managerAssigned: "Alice Johnson",
			vehicle: "Tesla Model S",
			phone: "+1 234 567 8901",
		},
		{
			name: "Jane Smith",
			location: "Los Angeles",
			managerAssigned: "Bob Brown",
			vehicle: "Ford F-150",
			phone: "+1 987 654 3210",
		},
		{
			name: "Michael Brown",
			location: "Chicago",
			managerAssigned: "Sarah Lee",
			vehicle: "Chevrolet Bolt",
			phone: "+1 312 555 7890",
		},
		{
			name: "Emily Davis",
			location: "Houston",
			managerAssigned: "Tom Wilson",
			vehicle: "Nissan Leaf",
			phone: "+1 713 444 5678",
		},
		{
			name: "Daniel Martinez",
			location: "Phoenix",
			managerAssigned: "Jessica White",
			vehicle: "BMW i3",
			phone: "+1 602 999 4321",
		},
		{
			name: "Sophia Miller",
			location: "Philadelphia",
			managerAssigned: "Mark Adams",
			vehicle: "Audi e-tron",
			phone: "+1 215 777 6543",
		},
		{
			name: "James Anderson",
			location: "San Antonio",
			managerAssigned: "Emma Thomas",
			vehicle: "Hyundai Kona EV",
			phone: "+1 210 321 8765",
		},
		{
			name: "James Anderson",
			location: "San Antonio",
			managerAssigned: "Emma Thomas",
			vehicle: "Hyundai Kona EV",
			phone: "+1 210 321 8765",
		},
	];

	const adminData = admins.length ? admins : staticAdmins;

	const filteredAdmins = adminData.filter((admin) =>
		admin.name.toLowerCase().includes(searchQuery.toLowerCase())
	);

	const indexOfLastAdmin = currentPage * adminsPerPage;
	const indexOfFirstAdmin = indexOfLastAdmin - adminsPerPage;
	const currentAdmins = filteredAdmins.slice(
		indexOfFirstAdmin,
		indexOfLastAdmin
	);

	const handlePageChange = (event, value) => {
		setCurrentPage(value);
	};

	return (
		<Box
			sx={{
				width: "calc(100% - 48px)",
				margin: "0 auto",
				padding: "24px",
				backgroundColor: "#1C1C1C",
				borderRadius: "12px",
			}}
		>
			<Typography
				sx={{
					color: "#FFFFFF",
					fontWeight: 500,
					fontSize: "18px",
					fontFamily: "Gilroy",
				}}
			>
				Charge stations
			</Typography>

			{/* Search & Buttons Section */}
			<Box
				sx={{
					display: "flex",
					gap: "16px",
					marginTop: "16px",
					alignItems: "center",
					fontFamily: "Gilroy",
				}}
			>
				<TextField
					variant="outlined"
					placeholder="Search Charge stations"
					sx={{
						width: "422px",
						backgroundColor: "#272727",

						borderRadius: "12px",
						input: { color: "#FFFFFF" },
						"& .MuiOutlinedInput-root": {
							borderRadius: "12px",
							"& fieldset": { borderColor: "#FFFFFF" },
							"&:hover fieldset": { borderColor: "#FFFFFF" },
							"&.Mui-focused fieldset": {
								borderColor: "#52ACDF",
							},
						},
					}}
					InputProps={{
						startAdornment: (
							<InputAdornment position="start">
								<SearchIcon sx={{ color: "#FFFFFF" }} />
							</InputAdornment>
						),
					}}
					value={searchQuery}
					onChange={(e) => setSearchQuery(e.target.value)}
				/>
				<Box
					sx={{
						display: "flex",
						justifyContent: "flex-end",
						width: "100%",
					}}
				>
					<Button
						sx={{
							backgroundColor: "#52ACDF",
							color: "white",
							borderRadius: "8px",
							width: "184px",
							"&:hover": {
								backgroundColor: "#439BC1",
							},
						}}
					>
						Add Charge Stations
					</Button>
				</Box>

				<IconButton
					sx={{
						width: "44px",
						height: "44px",
						borderRadius: "8px",
						backgroundColor: "#272727",
						color: "#52ACDF",
						"&:hover": { backgroundColor: "#333333" },
					}}
				>
					<TuneIcon />
				</IconButton>
			</Box>

			{/* Table Section */}
			<TableContainer
				component={Paper}
				sx={{
					marginTop: "24px",
					backgroundColor: "#1C1C1C",
					borderRadius: "12px",
					overflow: "hidden",
				}}
			>
				<Table>
					<TableHead sx={{ backgroundColor: "#272727" }}>
						<TableRow>
							{[
								"Name",
								"Location",
								"Manager Assigned",
								"Vehicle",
								"Phone Number",
								"Action",
							].map((header) => (
								<TableCell
									key={header}
									sx={{
										color: "#FFFFFF",
										fontWeight: "bold",
									}}
								>
									{header}
								</TableCell>
							))}
						</TableRow>
					</TableHead>
					<TableBody>
						{currentAdmins.map((admin, index) => (
							<TableRow
								key={index}
								sx={{ backgroundColor: "#1C1C1C" }}
							>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{admin.name}
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{admin.location || "N/A"}
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{admin.managerAssigned || "N/A"}
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{admin.vehicle || "N/A"}{" "}
									<Typography
										component="span"
										sx={{
											color: "#52ACDF",
											cursor: "pointer",
											textDecoration: "none",
											"&:hover": {
												textDecoration: "underline",
											},
										}}
									>
										+6 more
									</Typography>
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{admin.phone}
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									<IconButton size="small">
										<MoreHorizIcon
											sx={{ color: "#FFFFFF" }}
										/>
									</IconButton>
								</TableCell>
							</TableRow>
						))}
					</TableBody>
				</Table>
			</TableContainer>

			{/* Pagination */}
			<Box
				sx={{
					display: "flex",
					justifyContent: "flex-end",
					alignItems: "center",
					marginTop: "16px",
					width: "100%",
					gap: "8px",
				}}
			>
				<Typography
					sx={{ color: "white", fontSize: "16px", fontWeight: 500 }}
				>
					Page Number :
				</Typography>
				<Pagination
					count={Math.ceil(filteredAdmins.length / adminsPerPage)}
					page={currentPage}
					onChange={handlePageChange}
					siblingCount={0}
					boundaryCount={0}
					sx={{
						"& .MuiPaginationItem-root": {
							color: "white",
							borderRadius: "0px",
						},
						"& .MuiPaginationItem-page.Mui-selected": {
							backgroundColor: "transparent",
							fontWeight: "bold",
							color: "#FFFFFF",
						},
					}}
				/>
			</Box>
		</Box>
	);
}
