import { useEffect, useState } from "react";
import {
	Box,
	Button,
	Typography,
	TextField,
	InputAdornment,
	Paper,
	Table,
	TableBody,
	TableCell,
	TableContainer,
	TableHead,
	TableRow,
	Pagination,
	IconButton,
} from "@mui/material";
import SearchIcon from "@mui/icons-material/Search";
import MoreHorizIcon from "@mui/icons-material/MoreHoriz";
import TuneIcon from "@mui/icons-material/Tune";
import { useDispatch, useSelector } from "react-redux";
import { userList } from "../../redux/slices/userSlice"; // Make sure userSlice exists
import { AppDispatch, RootState } from "../../redux/store/store";

export default function UserList() {
	const [searchQuery, setSearchQuery] = useState("");
	const [currentPage, setCurrentPage] = useState(1);
	const usersPerPage = 10;

	const dispatch = useDispatch<AppDispatch>();
	const users = useSelector((state: RootState) => state.userReducer.users);

	useEffect(() => {
		dispatch(userList());
	}, [dispatch]);

	const staticUsers = [
		{
			name: "Alice Johnson",
			email: "alice@example.com",
			role: "User",
			phone: "+1 234 567 8901",
		},
		{
			name: "Bob Brown",
			email: "bob@example.com",
			role: "Admin",
			phone: "+1 987 654 3210",
		},
		{
			name: "Charlie Davis",
			email: "charlie@example.com",
			role: "User",
			phone: "+1 312 555 7890",
		},
		{
			name: "Alice Johnson",
			email: "alice@example.com",
			role: "User",
			phone: "+1 234 567 8901",
		},
		{
			name: "Bob Brown",
			email: "bob@example.com",
			role: "Admin",
			phone: "+1 987 654 3210",
		},
		{
			name: "Charlie Davis",
			email: "charlie@example.com",
			role: "User",
			phone: "+1 312 555 7890",
		},
		{
			name: "Bob Brown",
			email: "bob@example.com",
			role: "Admin",
			phone: "+1 987 654 3210",
		},
		{
			name: "Charlie Davis",
			email: "charlie@example.com",
			role: "User",
			phone: "+1 312 555 7890",
		},
	];

	const userData = users.length ? users : staticUsers;

	const filteredUsers = userData.filter((user) =>
		user.name.toLowerCase().includes(searchQuery.toLowerCase())
	);

	const indexOfLastUser = currentPage * usersPerPage;
	const indexOfFirstUser = indexOfLastUser - usersPerPage;
	const currentUsers = filteredUsers.slice(indexOfFirstUser, indexOfLastUser);

	const handlePageChange = (event, value) => {
		setCurrentPage(value);
	};

	return (
		<Box
			sx={{
				width: "calc(100% - 48px)",
				margin: "0 auto",
				padding: "24px",
				backgroundColor: "#1C1C1C",
				borderRadius: "12px",
			}}
		>
			<Typography
				sx={{
					color: "#FFFFFF",
					fontWeight: 500,
					fontSize: "18px",
					fontFamily: "Gilroy",
				}}
			>
				User List
			</Typography>

			{/* Search & Buttons Section */}
			<Box
				sx={{
					display: "flex",
					gap: "16px",
					marginTop: "16px",
					alignItems: "center",
					fontFamily: "Gilroy",
				}}
			>
				<TextField
					variant="outlined"
					placeholder="Search Users"
					sx={{
						width: "422px",
						backgroundColor: "#272727",
						borderRadius: "12px",
						input: { color: "#FFFFFF" },
						"& .MuiOutlinedInput-root": {
							borderRadius: "12px",
							"& fieldset": { borderColor: "#FFFFFF" },
							"&:hover fieldset": { borderColor: "#FFFFFF" },
							"&.Mui-focused fieldset": {
								borderColor: "#52ACDF",
							},
						},
					}}
					InputProps={{
						startAdornment: (
							<InputAdornment position="start">
								<SearchIcon sx={{ color: "#FFFFFF" }} />
							</InputAdornment>
						),
					}}
					value={searchQuery}
					onChange={(e) => setSearchQuery(e.target.value)}
				/>
				<Box
					sx={{
						display: "flex",
						justifyContent: "flex-end",
						width: "100%",
					}}
				>
					<Button
						sx={{
							backgroundColor: "#52ACDF",
							color: "white",
							borderRadius: "8px",
							width: "184px",
							"&:hover": { backgroundColor: "#439BC1" },
						}}
					>
						Add User
					</Button>
				</Box>

				<IconButton
					sx={{
						width: "44px",
						height: "44px",
						borderRadius: "8px",
						backgroundColor: "#272727",
						color: "#52ACDF",
						"&:hover": { backgroundColor: "#333333" },
					}}
				>
					<TuneIcon />
				</IconButton>
			</Box>

			{/* Table Section */}
			<TableContainer
				component={Paper}
				sx={{
					marginTop: "24px",
					backgroundColor: "#1C1C1C",
					borderRadius: "12px",
					overflow: "hidden",
				}}
			>
				<Table>
					<TableHead sx={{ backgroundColor: "#272727" }}>
						<TableRow>
							{["Name", "Email", "Role", "Phone", "Action"].map(
								(header) => (
									<TableCell
										key={header}
										sx={{
											color: "#FFFFFF",
											fontWeight: "bold",
										}}
									>
										{header}
									</TableCell>
								)
							)}
						</TableRow>
					</TableHead>
					<TableBody>
						{currentUsers.map((user, index) => (
							<TableRow
								key={index}
								sx={{ backgroundColor: "#1C1C1C" }}
							>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{user.name}
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{user.email}
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{user.role}
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									{user.phone}
								</TableCell>
								<TableCell
									sx={{
										color: "#FFFFFF",
										borderBottom: "1px solid #2A2A2A",
									}}
								>
									<IconButton size="small">
										<MoreHorizIcon
											sx={{ color: "#FFFFFF" }}
										/>
									</IconButton>
								</TableCell>
							</TableRow>
						))}
					</TableBody>
				</Table>
			</TableContainer>

			{/* Pagination */}
			<Box
				sx={{
					display: "flex",
					justifyContent: "flex-end",
					alignItems: "center",
					marginTop: "16px",
				}}
			>
				<Typography
					sx={{ color: "white", fontSize: "16px", fontWeight: 500 }}
				>
					Page Number :
				</Typography>
				<Pagination
					count={Math.ceil(filteredUsers.length / usersPerPage)}
					page={currentPage}
					onChange={handlePageChange}
					siblingCount={0}
					boundaryCount={0}
					sx={{
						"& .MuiPaginationItem-root": {
							color: "white",
							borderRadius: "0px",
						},
						"& .MuiPaginationItem-page.Mui-selected": {
							backgroundColor: "transparent",
							fontWeight: "bold",
							color: "#FFFFFF",
						},
					}}
				/>
			</Box>
		</Box>
	);
}
